@@ -2,8 +2,6 @@ import * as FourSlash from "./_namespaces/FourSlash";
 import {
     CompilerBaselineRunner,
     CompilerTestType,
-    DefinitelyTypedRunner,
-    DockerfileRunner,
     FourSlashRunner,
     GeneratedFourslashRunner,
     IO,
@@ -12,9 +10,7 @@ import {
     setLightMode,
     setShardId,
     setShards,
-    Test262BaselineRunner,
     TestRunnerKind,
-    UserCodeRunner,
 } from "./_namespaces/Harness";
 import * as project from "./_namespaces/project";
 import * as RWC from "./_namespaces/RWC";
@@ -78,14 +74,6 @@ export function createRunner(kind: TestRunnerKind): RunnerBase {
             return new project.ProjectRunner();
         case "rwc":
             return new RWC.RWCRunner();
-        case "test262":
-            return new Test262BaselineRunner();
-        case "user":
-            return new UserCodeRunner();
-        case "dt":
-            return new DefinitelyTypedRunner();
-        case "docker":
-            return new DockerfileRunner();
     }
     return ts.Debug.fail(`Unknown runner kind ${kind}`);
 }
@@ -220,18 +208,6 @@ function handleTestConfig() {
                     case "rwc":
                         runners.push(new RWC.RWCRunner());
                         break;
-                    case "test262":
-                        runners.push(new Test262BaselineRunner());
-                        break;
-                    case "user":
-                        runners.push(new UserCodeRunner());
-                        break;
-                    case "dt":
-                        runners.push(new DefinitelyTypedRunner());
-                        break;
-                    case "docker":
-                        runners.push(new DockerfileRunner());
-                        break;
                 }
             }
         }
@@ -250,12 +226,6 @@ function handleTestConfig() {
         runners.push(new FourSlashRunner(FourSlash.FourSlashTestType.ShimsWithPreprocess));
         runners.push(new FourSlashRunner(FourSlash.FourSlashTestType.Server));
         // runners.push(new GeneratedFourslashRunner());
-
-        // CRON-only tests
-        if (process.env.TRAVIS_EVENT_TYPE === "cron") {
-            runners.push(new UserCodeRunner());
-            runners.push(new DockerfileRunner());
-        }
     }
     if (runUnitTests === undefined) {
         runUnitTests = runners.length !== 1; // Don't run unit tests when running only one runner if unit tests were not explicitly asked for
