@@ -35,6 +35,26 @@ function f12({ kind, payload }: Action) {
     }
 }
 
+// repro #50206
+function f13<T extends Action>({ kind, payload }: T) {
+    if (kind === 'A') {
+        payload.toFixed();
+    }
+    if (kind === 'B') {
+        payload.toUpperCase();
+    }
+}
+
+function f14<T extends Action>(t: T) {
+    const { kind, payload } = t;
+    if (kind === 'A') {
+        payload.toFixed();
+    }
+    if (kind === 'B') {
+        payload.toUpperCase();
+    }
+}
+
 type Action2 =
     | { kind: 'A', payload: number | undefined }
     | { kind: 'B', payload: string | undefined };
@@ -367,6 +387,21 @@ const fa3: (...args: [true, number] | [false, string]) => void = (guard, value)
     }
 }
 
+// Repro from #52152
+
+interface ClientEvents {
+    warn: [message: string];
+    shardDisconnect: [closeEvent: CloseEvent, shardId: number];
+}
+  
+declare class Client {
+    public on<K extends keyof ClientEvents>(event: K, listener: (...args: ClientEvents[K]) => void): void;
+}
+
+const bot = new Client();
+bot.on("shardDisconnect", (event, shard) => console.log(`Shard ${shard} disconnected (${event.code},${event.wasClean}): ${event.reason}`));
+bot.on("shardDisconnect", event => console.log(`${event.code} ${event.wasClean} ${event.reason}`));
+
 
 //// [dependentDestructuredVariables.js]
 "use strict";
@@ -420,6 +455,24 @@ function f12({ kind, payload }) {
             payload; // never
     }
 }
+// repro #50206
+function f13({ kind, payload }) {
+    if (kind === 'A') {
+        payload.toFixed();
+    }
+    if (kind === 'B') {
+        payload.toUpperCase();
+    }
+}
+function f14(t) {
+    const { kind, payload } = t;
+    if (kind === 'A') {
+        payload.toFixed();
+    }
+    if (kind === 'B') {
+        payload.toUpperCase();
+    }
+}
 function f20({ kind, payload }) {
     if (payload) {
         if (kind === 'A') {
@@ -649,10 +702,13 @@ const fa3 = (guard, value) => {
         }
     }
 };
+const bot = new Client();
+bot.on("shardDisconnect", (event, shard) => console.log(`Shard ${shard} disconnected (${event.code},${event.wasClean}): ${event.reason}`));
+bot.on("shardDisconnect", event => console.log(`${event.code} ${event.wasClean} ${event.reason}`));
 
 
 //// [dependentDestructuredVariables.d.ts]
-declare type Action = {
+type Action = {
     kind: 'A';
     payload: number;
 } | {
@@ -662,7 +718,9 @@ declare type Action = {
 declare function f10({ kind, payload }: Action): void;
 declare function f11(action: Action): void;
 declare function f12({ kind, payload }: Action): void;
-declare type Action2 = {
+declare function f13<T extends Action>({ kind, payload }: T): void;
+declare function f14<T extends Action>(t: T): void;
+type Action2 = {
     kind: 'A';
     payload: number | undefined;
 } | {
@@ -673,7 +731,7 @@ declare function f20({ kind, payload }: Action2): void;
 declare function f21(action: Action2): void;
 declare function f22(action: Action2): void;
 declare function f23({ kind, payload }: Action2): void;
-declare type Foo = {
+type Foo = {
     kind: 'A';
     isA: true;
 } | {
@@ -684,7 +742,7 @@ declare type Foo = {
     isA: false;
 };
 declare function f30({ kind, isA }: Foo): void;
-declare type Args = ['A', number] | ['B', string];
+type Args = ['A', number] | ['B', string];
 declare function f40(...[kind, data]: Args): void;
 interface A<T> {
     variant: 'a';
@@ -694,11 +752,11 @@ interface B<T> {
     variant: 'b';
     value: Array<T>;
 }
-declare type AB<T> = A<T> | B<T>;
+type AB<T> = A<T> | B<T>;
 declare function printValue<T>(t: T): void;
 declare function printValueList<T>(t: Array<T>): void;
 declare function unrefined1<T>(ab: AB<T>): void;
-declare type Action3 = {
+type Action3 = {
     type: 'add';
     payload: {
         toAdd: number;
@@ -716,7 +774,7 @@ declare function f50(cb: (...args: Args) => void): void;
 declare const f51: (...args: ['A', number] | ['B', string]) => void;
 declare const f52: (...args: ['A', number] | ['B']) => void;
 declare function readFile(path: string, callback: (...args: [err: null, data: unknown[]] | [err: Error, data: undefined]) => void): void;
-declare type ReducerArgs = ["add", {
+type ReducerArgs = ["add", {
     a: number;
     b: number;
 }] | ["concat", {
@@ -724,7 +782,7 @@ declare type ReducerArgs = ["add", {
     secondArr: any[];
 }];
 declare const reducer: (...args: ReducerArgs) => void;
-declare type FooMethod = {
+type FooMethod = {
     method(...args: [
         type: "str",
         cb: (e: string) => void
@@ -734,7 +792,7 @@ declare type FooMethod = {
     ]): void;
 };
 declare let fooM: FooMethod;
-declare type FooAsyncMethod = {
+type FooAsyncMethod = {
     method(...args: [
         type: "str",
         cb: (e: string) => void
@@ -744,7 +802,7 @@ declare type FooAsyncMethod = {
     ]): Promise<any>;
 };
 declare let fooAsyncM: FooAsyncMethod;
-declare type FooGenMethod = {
+type FooGenMethod = {
     method(...args: [
         type: "str",
         cb: (e: string) => void
@@ -754,7 +812,7 @@ declare type FooGenMethod = {
     ]): Generator<any, any, any>;
 };
 declare let fooGenM: FooGenMethod;
-declare type FooAsyncGenMethod = {
+type FooAsyncGenMethod = {
     method(...args: [
         type: "str",
         cb: (e: string) => void
@@ -764,7 +822,7 @@ declare type FooAsyncGenMethod = {
     ]): AsyncGenerator<any, any, any>;
 };
 declare let fooAsyncGenM: FooAsyncGenMethod;
-declare type Func = <T extends ["a", number] | ["b", string]>(...args: T) => void;
+type Func = <T extends ["a", number] | ["b", string]>(...args: T) => void;
 declare const f60: Func;
 declare function foo({ value1, test1, test2, test3, test4, test5, test6, test7, test8, test9 }: {
     value1: any;
@@ -787,3 +845,11 @@ declare function fa2(x: {
     value: string;
 }): void;
 declare const fa3: (...args: [true, number] | [false, string]) => void;
+interface ClientEvents {
+    warn: [message: string];
+    shardDisconnect: [closeEvent: CloseEvent, shardId: number];
+}
+declare class Client {
+    on<K extends keyof ClientEvents>(event: K, listener: (...args: ClientEvents[K]) => void): void;
+}
+declare const bot: Client;
