@@ -8,6 +8,11 @@ for (const zoneName of timezoneNames) {
   });
 }
 
+const enumerationKeys = ['calendar', 'collation', 'currency', 'numberingSystem', 'timeZone', 'unit'] as const;
+for (const key of enumerationKeys) {
+  var supported = Intl.supportedValuesOf(key);
+}
+
 
 //// [es2022IntlAPIs.js]
 // https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/DateTimeFormat/DateTimeFormat#using_timezonename
@@ -18,3 +23,7 @@ for (const zoneName of timezoneNames) {
         timeZoneName: zoneName,
     });
 }
+const enumerationKeys = ['calendar', 'collation', 'currency', 'numberingSystem', 'timeZone', 'unit'];
+for (const key of enumerationKeys) {
+    var supported = Intl.supportedValuesOf(key);
+}
