@@ -21,5 +21,5 @@ module.exports.additional = 20;
 
 
 //// [index.d.ts]
-export const member: number;
-export const additional: 20;
+export let member: number;
+export let additional: 20;
