@@ -14,4 +14,4 @@
 //// import Foo from './foo';
 //// const a = <[|/*use*/Foo|] />
 
-verify.goToDefinition("use", "def");
\ No newline at end of file
+verify.baselineGoToDefinition("use");
\ No newline at end of file
