@@ -7,5 +7,4 @@
 //// */
 ////function f() {}
 
-goTo.marker("use");
-verify.goToDefinitionIs("def");
+verify.baselineGetDefinitionAtPosition("use");
