@@ -17,8 +17,9 @@ verify.noErrors();
 const ranges = test.ranges();
 const [r0Def, r0, r1Def, r1, r2Def, r2, r3] = ranges;
 const importRanges = [r2, r3];
-verify.renameLocations(r0, [r0, { range: r1, suffixText: " as C" }]); //, r1
-verify.renameLocations(r1, [{ range: r1, prefixText: "C as " }, r2, r3]);
-verify.renameLocations(importRanges, [{ range: r2, prefixText: "C as " }, r3]);
-
-verify.baselineFindAllReferences('1', '2', '3')
+verify.baselineCommands(
+    { type: "findAllReferences", markerOrRange: ['1', '2', '3'] },
+    { type: "findRenameLocations", markerOrRange: r0 },
+    { type: "findRenameLocations", markerOrRange: r1 },
+    { type: "findRenameLocations", markerOrRange: importRanges },
+);
